ewa._ruletab

Package ewa :: Module _ruletab |
[hide private]
[frames] | no frames]

# Module _ruletab

source code

Variables | [hide private]
| _lr_method = ``'``LALR``'``
| _lr_signature = ``'``\xeb\xd1\x15\xf2`\xde\xf7\xa2\x9b\xd5\xb8i\xb``...``
| _lr_action = ``{`0`:` `{``'``AND``'``:` 23`,` `'``BAREREGEX``'``:` 31`,` `'``BAREWORD``'``:` 11`,` `...``
| _lr_goto = ``{`0`:` `{``'``cond``'``:` 4`,` `'``cond_expr``'``:` 25`,` `'``cond_op``'``:` 19`,` `'``co``...``
| _lr_productions = ``[``(``'``S\'``'``,` 1`,` None`,` None`,` None`)``,` `(``'``grammar``'``,` 1`...``
| __package__ = `None`
| _k = ``'``cond_list``'``
| _v = ``(``[`46`,` 84`]``,` `[`68`,` 93`]``)``
| _x = `84`
| _y = `93`

Variables Details | [hide private]

  ### _lr_signature Value:
      '\xeb\xd1\x15\xf2`\xde\xf7\xa2\x9b\xd5\xb8i\xb9GC9'

  ### _lr_action Value:
      {0: {'AND': 23,
           'BAREREGEX': 31,
           'BAREWORD': 11,
           'DATE': 6,
           'DATETIME': 17,
           'DEFAULT': 1,
           'LBRACK': 26,
           'NOT': 30,
      ...

  ### _lr_goto Value:
      {0: {'cond': 4,
           'cond_expr': 25,
           'cond_op': 19,
           'cond_rule': 28,
           'cond_rule_list': 29,
           'date': 21,
           'datecompare': 7,
           'datespec': 5,
      ...

  ### _lr_productions Value:
      [('S\'', 1, None, None, None),
       ('grammar', 1, 'p_grammar', 'ewa/ruleparser.py', 149),
       ('cond_rule_list', 1, 'p_cond_rule_list', 'ewa/ruleparser.py', 153),
       ('cond_rule_list', 3, 'p_cond_rule_list', 'ewa/ruleparser.py', 154),
       ('cond_rule_list', 2, 'p_cond_rule_list', 'ewa/ruleparser.py', 155),
       ('rulelist', 3, 'p_rulelist_1', 'ewa/ruleparser.py', 165),
       ('rulelist', 2, 'p_rulelist_2', 'ewa/ruleparser.py', 169),
       ('cond_rule', 3, 'p_cond_rule', 'ewa/ruleparser.py', 173),
      ...